==> dl.php?src=linea21_1_6.zip: linea21/languages/fr/lang_contents.utf-8.php <==
<?php
/**
 * @package linea21.languages
 * @subpackage fr
 * @author linea21 <info@linea21.com>
 * @version $id SVN
 * @access public
 * @license http://opensource.org/licenses/gpl-3.0.html
 */




/*	nommage des modules
 *  	*/
$lang['contents']['name']='partie';
$lang['contents']['confirm_add'] = "Ajout de la partie réalisé avec succès\n";
$lang['contents']['confirm_mod'] = "Modification de la partie réalisée avec succès\n";
$lang['contents']['confirm_sup'] ="Suppression d'une partie réalisée avec succès\n";

/*	nommage des 'parents'
 *  	*/
$lang['contents']['publication_type']='dossier';
$lang['contents']['workshop_type']='compte-rendu';

/*	nommage rubrique module
 *  	*/
$lang['contents']['add']= 'Ajout d\'une '.$lang['contents']['name'];
$lang['contents']['mod']= 'Modification d\'une '.$lang['contents']['name'];
$lang['contents']['sup']= 'Suppression d\'une '.$lang['contents']['name'];
$lang['contents']['det']= 'Détail d\'une  '.$lang['contents']['name'];
$lang['contents']['go_back']='Retour au ';


/*	nommage rubrique add / mod /det
 *  	*/
$lang['contents']['add_title']='Saisie des informations d\'une nouvelle '.$lang['contents']['name'];
$lang['contents']['mod_title']='Modification des informations de la '.$lang['contents']['name'];


/*	check integrité des données
 *  	*/
$lang['contents']['no_title'] = 'Il est nécessaire de donner un titre à la partie en cours de création.';
$lang['contents']['no_body'] = 'Il est nécessaire de fournir un contenu à la partie en cours de création.';


/*	nommage élément rubrique
 *  	*/
$lang['contents']['supp_info']='Vous avez choisi de supprimer la partie suivante : ';
$lang['contents']['title']='titre';
$lang['contents']['body']='contenu de la partie';

/*	nommage quickbox
 *  	*/
$lang['contents']['qb_titleadd']=' derniers ajouts effectués';
$lang['contents']['qb_titlemod']=' dernières modifications effectuées';
$lang['contents']['qb_titlesup']=' dernières suppressions effectuées';
$lang['contents']['qb_titlepubli']=' dernières publications effectuées';
$lang['contents']['qb_title_type_W']=' sur le compte rendu';
$lang['contents']['qb_title_type_P']=' sur le dossier';


/*	rubrique d'aide
 *  	*/
$lang['contents']['help_add1']='Pour ajouter une partie, vous devez saisir les informations requises dans le formulaire ci-dessus.';
$lang['contents']['help_add2']='Après avoir validé le formulaire d\'ajout, vérifiez vos données dans le récapitulatif';
$lang['contents']['help_add3']='Si le récapitulatif ne vous convient pas, vous pouvez cliquer sur \'revoir les paramètres\' pour les modifier';

$lang['contents']['help_mod1']='Vous pouvez modifier l\'ensemble des champs qui vous sont accessibles dans le formulaire ci-dessus';
$lang['contents']['help_mod2']='Après avoir validé le formulaire de modification, vérifiez les paramètres dans le récapitulatif';
$lang['contents']['help_mod3']='Si le récapitulatif ne vous convient pas, vous pouvez cliquer sur \'revoir les paramètres\' pour modifier de nouveau les données';


$lang['contents']['help_det1']='Vous pouvez modifier les caractéristiques de cette partie en cliquant sur l\'icone de modification qui lui est associée';
$lang['contents']['help_det2']='Vous pouvez supprimer cette partie en cliquant sur l\'icone de suppression qui lui est associée';

$lang['contents']['help_sup1']='Si vous ne souhaitez pas confirmer la suppression de cette partie, cliquer sur \'Annuler\'.';


?>

==> dl.php?src=linea21_1_7.zip: linea21/languages/fr/lang_contents.utf-8.php <==
<?php
/**
 * @package linea21.languages
 * @subpackage fr
 * @author linea21 <info@linea21.com>
 * @version $id SVN
 * @access public
 * @license http://opensource.org/licenses/gpl-3.0.html
 */




/*	nommage des modules
 *  	*/
$lang['contents']['name']='partie';
$lang['contents']['confirm_add'] = "Ajout de la partie réalisé avec succès\n";
$lang['contents']['confirm_mod'] = "Modification de la partie réalisée avec succès\n";
$lang['contents']['confirm_sup'] ="Suppression d'une partie réalisée avec succès\n";

/*	nommage des 'parents'
 *  	*/
$lang['contents']['publication_type']='publication';
$lang['contents']['workshop_type']='compte-rendu';

/*	nommage rubrique module
 *  	*/
$lang['contents']['add']= 'Ajout d\'une '.$lang['contents']['name'];
$lang['contents']['mod']= 'Modification d\'une '.$lang['contents']['name'];
$lang['contents']['sup']= 'Suppression d\'une '.$lang['contents']['name'];
$lang['contents']['det']= 'Détail d\'une  '.$lang['contents']['name'];
$lang['contents']['go_back']='Retour à la ';


/*	nommage rubrique add / mod /det
 *  	*/
$lang['contents']['add_title']='Saisie des informations d\'une nouvelle '.$lang['contents']['name'];
$lang['contents']['mod_title']='Modification des informations de la '.$lang['contents']['name'];


/*	check integrité des données
 *  	*/
$lang['contents']['no_title'] = 'Il est nécessaire de donner un titre à la partie en cours de création.';
$lang['contents']['no_body'] = 'Il est nécessaire de fournir un contenu à la partie en cours de création.';


/*	nommage élément rubrique
 *  	*/
$lang['contents']['supp_info']='Vous avez choisi de supprimer la partie suivante : ';
$lang['contents']['title']='titre';
$lang['contents']['body']='contenu de la partie';

/*	nommage quickbox
 *  	*/
$lang['contents']['qb_titleadd']=' derniers ajouts effectués';
$lang['contents']['qb_titlemod']=' dernières modifications effectuées';
$lang['contents']['qb_titlesup']=' dernières suppressions effectuées';
$lang['contents']['qb_titlepubli']=' dernières publications effectuées';
$lang['contents']['qb_title_type_W']=' sur le compte rendu';
$lang['contents']['qb_title_type_P']=' sur la publication';


/*	rubrique d'aide
 *  	*/
$lang['contents']['help_add1']='Pour ajouter une partie, vous devez saisir les informations requises dans le formulaire ci-dessus.';
$lang['contents']['help_add2']='Après avoir validé le formulaire d\'ajout, vérifiez vos données dans le récapitulatif';
$lang['contents']['help_add3']='Si le récapitulatif ne vous convient pas, vous pouvez cliquer sur \'revoir les paramètres\' pour les modifier';

$lang['contents']['help_mod1']='Vous pouvez modifier l\'ensemble des champs qui vous sont accessibles dans le formulaire ci-dessus';
$lang['contents']['help_mod2']='Après avoir validé le formulaire de modification, vérifiez les paramètres dans le récapitulatif';
$lang['contents']['help_mod3']='Si le récapitulatif ne vous convient pas, vous pouvez cliquer sur \'revoir les paramètres\' pour modifier de nouveau les données';


$lang['contents']['help_det1']='Vous pouvez modifier les caractéristiques de cette partie en cliquant sur l\'icone de modification qui lui est associée';
$lang['contents']['help_det2']='Vous pouvez supprimer cette partie en cliquant sur l\'icone de suppression qui lui est associée';

$lang['contents']['help_sup1']='Si vous ne souhaitez pas confirmer la suppression de cette partie, cliquer sur \'Annuler\'.';


?>
